Enum TimestampMode

pub enum TimestampMode {
    Always,
    Automatic {
        mark_added_timestamps: bool,
    },
    Never,
}

Variants



Always

Always add a timestamp



Automatic

Add a timestamp if none is found, checking each line

Fields

mark_added_timestamps: bool

Whether a “,” is appended to timestamps that the logger daemon adds (could be useful if the app itself (usually) also adds timestamps, to be able to distinguish, since there is a time delay for the times from the logger daemon).



Never

Never add timestamps, assumes the application reliably adds them