Struct Logger

pub struct Logger {
    pub logging_opts: LoggingOpts,
    pub local_time_default: bool,
    pub timestamp_opts: TimestampOpts,
    pub dir_path: Arc<Path>,
}

Fields

logging_opts: LoggingOptslocal_time_default: bool

What the default should be if logging_opts does not specify a local_time setting (or specifies both ambiguously)

timestamp_opts: TimestampOptsdir_path: Arc<Path>

Implementations

Source

impl Logger

pub fn current_log_path(&self) -> PathBuf

pub fn rotate_logs(&self) -> Result<()>

Rename the “current.log” file (if present) to “000001.log” or similar, allocating a new number, and delete old log files if there are more than configured.

pub fn redirect_to_logger(self, session_pid: Pid) -> Result<(), DaemonError>

Fork off a logger process (it immediately starts a new unix session to avoid being killed when the parent process group is killed) and redirect stdout and stderr to it. session_pid is denoting the daemon instance (the parent process or rather process group), it is written to the log when the parent ends (or closes stderr and stdout). Make sure stdout and stderr are flushed before calling this method.