pub struct LoggingOpts {
pub local_time_opts: LocalTimeOpts,
pub max_log_file_size: u64,
pub max_log_files: Option<u32>,
}Fields
local_time_opts: LocalTimeOptsmax_log_file_size: u64The maximum size of the ‘current.log’ file in bytes before it is renamed and a new one opened.
max_log_files: Option<u32>The maximum number of numbered log files (i.e. excluding
current.log) before the oldest are deleted. Careful: as
many files are deleted as needed as necessary to get their
count down to the given number (giving 0 it will delete them
all)! None means, no files are ever deleted.
Implementations
Sourceimpl LoggingOpts
impl LoggingOpts
pub fn local_time(&self, default: bool) -> bool