pub struct TimestampOpts {
pub use_rfc3339: bool,
pub mode: TimestampMode,
}Expand description
These settings will better be set statically by the app, rather than exposed to the user, thus not deriving clap::Args.
Fields
use_rfc3339: boolWhether rfc3339 format is to be used (default: whatever chrono
uses for Display).
mode: TimestampModeTrait Implementations
Sourceimpl Clone for TimestampOpts
impl Clone for TimestampOpts
Sourcefn clone(&self) -> TimestampOpts
fn clone(&self) -> TimestampOpts
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for TimestampOpts
impl RefUnwindSafe for TimestampOpts
impl Send for TimestampOpts
impl Sync for TimestampOpts
impl Unpin for TimestampOpts
impl UnwindSafe for TimestampOpts