pub enum TimestampMode {
Always,
Automatic {
mark_added_timestamps: bool,
},
Never,
}Variants
Always
Always add a timestamp
Automatic
Add a timestamp if none is found, checking each line
Fields
Never
Never add timestamps, assumes the application reliably adds them